==> odoo12_addon_somconnexio-12.0.0.0.0rc49-py2.py3-none-any.whl: odoo/addons/somconnexio/__manifest__.py <==
{
    'name': "Odoo Som Connexió customizations",
    'version': '12.0.0.0.0-rc49',
    'depends': [
        'account_asset_management',
        'account_financial_report',
        'account_payment_mode',
        'account_payment_order',
        'account_payment_partner',
        'account_cancel',
        'account_due_list',
        'easy_my_coop_api',
        'easy_my_coop_es',
        'easy_my_coop_sponsorship',
        'l10n_es_account_asset',
        'sale_management',
        'contract',
        'crm_lead_product',
        'mass_mailing_list_dynamic',
        'web_favicon',
        'web_responsive',
        'web_decimal_numpad_dot',
        'web_no_bubble',
        'web_searchbar_full_width',
        'partner_firstname',
        'mail',
        'queue_job',
        'component_event',
        'stock',
        'l10n_es',
        'l10n_es_aeat_mod303',
        'l10n_es_aeat_mod390',
        'l10n_es_aeat_mod349',
        'l10n_es_aeat_mod111',
        'l10n_es_aeat_mod190',
        'l10n_es_partner',
        'mis_builder',
        'mis_builder_budget',
        'l10n_es_mis_report',
        'l10n_es_account_bank_statement_import_n43',
        'account_payment_return',
        'account_banking_sepa_credit_transfer',
        'account_banking_sepa_direct_debit',
        'base_import_async',
        'mail_activity_board',
        'mail_activity_done',
        'partner_priority',
        'contract_payment_mode',
        'contract_mandate',
    ],
    'external_dependencies': {
        'python': [
            'otrs_somconnexio',
            'faker',
            'pyopencell',
            'factory'
        ],
    },
    'author': "Coopdevs Treball SCCL",
    'website': 'https://coopdevs.org',
    'category': "Cooperative management",
    'description': """
    Odoo Som Connexió customizations.
    """,
    "license": "AGPL-3",
    'data': [
        'data/product_categories.xml',
        'views/account_invoice_form.xml',
        'views/subscription_request_view.xml',
        'views/coop_agreement_view.xml',
        'views/res_partner_view.xml',
        'views/contract_view.xml',
        'views/service_technology_service_supplier.xml',
        'views/product_pricelist_view.xml',
        'views/product_category_technology_supplier_view.xml',
        'views/previous_provider_view.xml',
        'views/menus.xml',
        'views/crm_lead.xml',
        'views/crm_lead_line.xml',
        'views/mobile_isp_info_view.xml',
        'views/broadband_isp_info_view.xml',
        'views/stock_move_line_view.xml',
        'views/stock_production_lot.xml',
        'views/mobile_service_contract_info_view.xml',
        'views/adsl_service_contract_info_view.xml',
        'views/vodafone_fiber_service_contract_info.xml',
        'views/mm_fiber_service_contract_info.xml',
        'views/product_product_view.xml',
        'security/ir.model.access.csv',
        'data/service_technology.xml',
        'data/service_supplier.xml',
        'data/service_technology_service_supplier.xml',
        'data/product.category.technology.supplier.csv',
        'data/product_attribute.xml',
        'data/product_attribute_value.xml',
        'data/product_product.xml',
        'data/product.template.attribute.line.csv',
        'data/product.template.csv',
        'data/account_chart_template_data.xml',
        'data/discovery_channel.xml',
        'data/account_group.xml',
        'data/account.account.template-sc.csv',
        'data/account_payment_term.xml',
        'data/company.xml',
        'data/res.partner.bank.xml',
        'data/account_journal.xml',
        'data/account_payment_mode.xml',
        'data/mail.mass_mailing.list.csv',
        'data/ir_sequence.xml',
        'data/res.users.xml',
        'data/previous.provider.csv',
        'views/contract_templates.xml',
        'data/ir_config_pararameter.xml',
        'data/contract_terminate_reason.xml',
        'wizards/crm_leads_validate/crm_leads_validate.xml',
        'wizards/contract_iban_change/contract_iban_change.xml',
        'wizards/contract_holder_change/contract_holder_change.xml',
        'wizards/contract_email_change/contract_email_change.xml',
        'wizards/contract_address_change/contract_address_change.xml',
        'wizards/contract_one_shot_request/contract_one_shot_request.xml',
        'wizards/contract_tariff_change/contract_tariff_change.xml',
        'wizards/move_line_add_to_payment_debit_order/move_line_add_to_payment_debit_order.xml',  # noqa
        'data/share_type.xml',
        'data/res.bank.csv',
        'views/account_tax_view.xml',
        'views/account_tax_view.xml',
        'reports/report_paperformat.xml',
        'reports/sim_sending_letter_template.xml',
        'reports/new_sim_sending_letter_template.xml',
        'views/act_account_move_to_account_move_line_open.xml',
        'data/partner_priority.xml',
        'reports/invoice_claim_1_template.xml',
        'data/mail_activity_type.xml',
        'views/mail_activity_view.xml',
        'views/open_boards_activities.xml',
        'wizards/invoice_claim_1_send/invoice_claim_1_send.xml'
    ],
    'demo': [
        'demo/partner.xml',
        'demo/subscription_requests.xml',
    ],
    'qweb': [
        'static/src/xml/contract_email.xml'
    ]

}

==> odoo12_addon_somconnexio-12.0.1.1.16-py2.py3-none-any.whl: odoo/addons/somconnexio/__manifest__.py <==
{
    'name': "Odoo Som Connexió customizations",
    'version': '12.0.1.1.16',
    'depends': [
        'account_asset_management',
        'account_banking_sepa_credit_transfer',
        'account_banking_sepa_direct_debit',
        'account_cancel',
        'account_chart_update',
        'account_due_list',
        'account_financial_report',
        'account_invoice_validation_queued',
        'account_payment_mode',
        'account_payment_order',
        'account_payment_partner',
        'account_payment_return',
        'base_automation',
        'base_import_async',
        'component_event',
        'contract',
        'contract_mandate',
        'contract_payment_mode',
        'crm_lead_product',
        'easy_my_coop_api',
        'easy_my_coop_es',
        'easy_my_coop_sponsorship',
        'l10n_es',
        'l10n_es_account_asset',
        'l10n_es_account_bank_statement_import_n43',
        'l10n_es_aeat_mod111',
        'l10n_es_aeat_mod190',
        'l10n_es_aeat_mod303',
        'l10n_es_aeat_mod349',
        'l10n_es_aeat_mod390',
        'l10n_es_mis_report',
        'l10n_es_partner',
        'mail',
        'mail_activity_board',
        'mail_activity_done',
        'mass_editing',
        'mass_mailing_list_dynamic',
        'mis_builder',
        'mis_builder_budget',
        'partner_firstname',
        'partner_priority',
        'queue_job',
        'sale_management',
        'stock',
        'web_decimal_numpad_dot',
        'web_favicon',
        'web_no_bubble',
        'web_responsive',
        'web_searchbar_full_width',
        'web_widget_open_tab',
    ],
    'external_dependencies': {
        'python': [
            'otrs_somconnexio',
            'faker',
            'pyopencell',
            'factory',
            'stdnum',
        ],
    },
    'author': "Coopdevs Treball SCCL",
    'website': 'https://coopdevs.org',
    'category': "Cooperative management",
    'description': """
    Odoo Som Connexió customizations.
    """,
    "license": "AGPL-3",
    'data': [
        'data/product_categories.xml',
        'views/account_invoice_view.xml',
        'views/subscription_request_view.xml',
        'views/coop_agreement_view.xml',
        'views/res_partner_view.xml',
        'security/res_groups.xml',
        'data/service_supplier.xml',
        'views/contract_view.xml',
        'views/service_technology_service_supplier.xml',
        'views/product_pricelist_view.xml',
        'views/product_category_technology_supplier_view.xml',
        'views/previous_provider_view.xml',
        'views/crm_lead_line.xml',
        'views/menus.xml',
        'views/crm_lead.xml',
        'views/mobile_isp_info_view.xml',
        'views/broadband_isp_info_view.xml',
        'views/stock_move_line_view.xml',
        'views/stock_production_lot.xml',
        'views/mobile_service_contract_info_view.xml',
        'views/adsl_service_contract_info_view.xml',
        'views/vodafone_fiber_service_contract_info.xml',
        'views/mm_fiber_service_contract_info.xml',
        'views/product_product_view.xml',
        'views/res_company_view.xml',
        'security/ir.model.access.csv',
        'data/service_technology.xml',
        'data/service_technology_service_supplier.xml',
        'data/product.category.technology.supplier.csv',
        'data/product_attribute.xml',
        'data/product_attribute_value.xml',
        'data/product_product.xml',
        'data/product.template.attribute.line.csv',
        'data/product.template.csv',
        'data/account_chart_template_data.xml',
        'data/discovery_channel.xml',
        'data/account_group.xml',
        'data/account.account.template-sc.csv',
        'data/account_payment_term.xml',
        'data/company.xml',
        'data/res.partner.bank.xml',
        'data/account_journal.xml',
        'data/account_payment_mode.xml',
        'data/mail.mass_mailing.list.csv',
        'data/ir_sequence.xml',
        'data/res.users.xml',
        'data/previous.provider.csv',
        'views/contract_templates.xml',
        'data/ir_config_pararameter.xml',
        'data/contract_terminate_reason.xml',
        'wizards/crm_leads_validate/crm_leads_validate.xml',
        'wizards/crm_lead_lines_validate/crm_lead_lines_validate.xml',
        'wizards/contract_iban_change/contract_iban_change.xml',
        'wizards/contract_holder_change/contract_holder_change.xml',
        'wizards/contract_email_change/contract_email_change.xml',
        'wizards/contract_address_change/contract_address_change.xml',
        'wizards/contract_one_shot_request/contract_one_shot_request.xml',
        'wizards/contract_tariff_change/contract_tariff_change.xml',
        'wizards/move_line_add_to_payment_debit_order/move_line_add_to_payment_debit_order.xml',  # noqa
        'wizards/create_lead_from_partner/create_lead_from_partner.xml',
        'data/share_type.xml',
        'data/res.bank.csv',
        'views/account_tax_view.xml',
        'views/account_tax_view.xml',
        'reports/report_paperformat.xml',
        'reports/sim_sending_letter_template.xml',
        'reports/new_sim_sending_letter_template.xml',
        'views/act_account_move_to_account_move_line_open.xml',
        'data/partner_priority.xml',
        'reports/invoice_claim_1_template.xml',
        'data/mail_activity_type.xml',
        'views/mail_activity_view.xml',
        'views/open_boards_activities.xml',
        'wizards/invoice_claim_1_send/invoice_claim_1_send.xml',
        'data/account_tax_group.xml',
        'data/account_tax.xml',
        'data/mis_report.xml',
        'wizards/create_subscription_from_partner/create_subscription_from_partner.xml',
        'reports/crm_lead_line_creation_email_template.xml',
        'data/base_automation.xml',
        'wizards/contract_invoice_payment/contract_invoice_payment.xml',
        'views/account_move_line.xml',
        'views/ir_action_view.xml',
        'data/mail_data.xml',
        'wizards/import_payment_group/import_payment_group.xml',
    ],
    'demo': [
        'demo/partner.xml',
        'demo/subscription_requests.xml',
    ],
    'qweb': [
        'static/src/xml/contract_email.xml',
        'static/src/xml/mail_chatter_buttons.xml',
    ]

}
